<?php

/**
 * Базовая модель от которой наследуются все остальные модели
 *
 * @abstract
 * @version 0.1 2010/09/01
 * @author webmaxx
 */
abstract class BaseModel extends CActiveRecord
{

    /**
     * Метод возвращает статичную модель указанного класса ActiveRecord
     *
     * @return object CActiveRecord
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Метод возвращает название таблицы БД, ассоциированной с данным классом
     *
     * @return string
     */
    public function tableName()
    {
        return get_class($this);
    }
    
    /*
     * Метод возвращает лимит для подстановки в урл
     * Можно юзать при формировании запросов через DAO
     * 
     * @version 0.1 2010/09/01
     * @since 0.1
     * @author webmaxx
     */
    public static function getLimit($rows=10, $page=1)
    {
        if (is_numeric($rows) && is_numeric($page)) {
            $page = (is_numeric($page) && $page > 0) ? $page : 1;
            $rows = (is_numeric($rows) && $rows > 0) ? $rows : 10;
            $offset = (($page-1)*$rows);
            $limit = ' LIMIT '.$offset.', '.$rows;
        } elseif (is_numeric($rows)) {
            $limit = ' LIMIT '.$rows;
        } else {
            $limit = '';
        }
        return $limit;
    }
    
    /*
     * Метод преобразует дату и возвращает её в формате timestamp
     * 
     * @version 0.1 2010/09/01
     * @since 0.1
     * @author webmaxx
     */
    public static function getTimeStampByDateTime($date=null, $format='Y-m-d H:i:s')
    {
        switch ($format) {
            case 'Y-m-d H:i:s':
                $date = explode(' ', $date);
                $time = explode(':', $date[1]);
                $date = explode('-', $date[0]);
                return mktime($time[0], $time[1], $time[2], $date[1], $date[2], $date[0]);
                break;
            case 'Y-m-d':
                $date = explode('-', $date);
                return mktime(0, 0, 0, $date[1], $date[2], $date[0]);
                break;
        }
    }

}
